==> suir-component-mapper-3.19.0.tgz: package/esm/checkbox/multiple-choice-list.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["label", "isDisabled"],
    _excluded2 = ["isRequired", "isReadOnly", "helperText", "validate", "isDisabled", "meta"],
    _excluded3 = ["className"],
    _excluded4 = ["className"],
    _excluded5 = ["FormFieldGridProps", "FormFieldProps", "HeaderProps", "OptionsListProps", "HelperTextProps"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React, { createContext, useContext } from 'react';
import PropTypes from 'prop-types';
import MultipleChoiceListCommon, { wrapperProps } from '@data-driven-forms/common/multiple-choice-list';
import FormCheckbox from "semantic-ui-react/dist/es/collections/Form/FormCheckbox.js";
import Header from "semantic-ui-react/dist/es/elements/Header/Header.js";
import FormField from "semantic-ui-react/dist/es/collections/Form/FormField.js";
import { createUseStyles } from "react-jss/dist/react-jss.esm.js";
import clsx from 'clsx';
import { validationError } from '../helpers/helpers';
import FormFieldGrid from '../form-field-grid/form-field-grid';
var useStyles = createUseStyles({
  header: {
    marginBottom: '0 !important',
    display: 'inline',
    fontSize: '0.92857143em !important'
  },
  error: {
    color: '#9f3a38 !important'
  },
  items: {
    marginBottom: '1em'
  },
  required: {
    '&:after': {
      content: '"*"',
      margin: '-0.2em 0 0 0.2em',
      color: '#db2828'
    }
  }
});
var CheckboxContext = /*#__PURE__*/createContext({});

var FinalCheckbox = function FinalCheckbox(_ref) {
  var label = _ref.label,
      _isDisabled = _ref.isDisabled,
      rest = _objectWithoutProperties(_ref, _excluded);

  var _useContext = useContext(CheckboxContext),
      _useContext$props = _useContext.props,
      isRequired = _useContext$props.isRequired,
      isReadOnly = _useContext$props.isReadOnly,
      helperText = _useContext$props.helperText,
      validate = _useContext$props.validate,
      isDisabled = _useContext$props.isDisabled,
      meta = _useContext$props.meta,
      props = _objectWithoutProperties(_useContext$props, _excluded2);

  return /*#__PURE__*/React.createElement(FormCheckbox, _extends({}, rest, props, {
    disabled: isDisabled,
    label: label
  }));
};

FinalCheckbox.propTypes = {
  isDisabled: PropTypes.bool,
  label: PropTypes.node
};

var Wrapper = function Wrapper(_ref2) {
  var _clsx;

  var label = _ref2.label,
      isRequired = _ref2.isRequired,
      children = _ref2.children,
      meta = _ref2.meta,
      validateOnMount = _ref2.validateOnMount,
      helperText = _ref2.helperText;
  var invalid = validationError(meta, validateOnMount);
  var classes = useStyles();

  var _useContext2 = useContext(CheckboxContext),
      FormFieldGridProps = _useContext2.FormFieldGridProps,
      FormFieldProps = _useContext2.FormFieldProps,
      HelperTextProps = _useContext2.HelperTextProps,
      _useContext2$OptionsL = _useContext2.OptionsListProps,
      optionsClassName = _useContext2$OptionsL.className,
      OptionsListProps = _objectWithoutProperties(_useContext2$OptionsL, _excluded3),
      _useContext2$HeaderPr = _useContext2.HeaderProps,
      headerClassname = _useContext2$HeaderPr.className,
      HeaderProps = _objectWithoutProperties(_useContext2$HeaderPr, _excluded4);

  return /*#__PURE__*/React.createElement(FormFieldGrid, _extends({
    helperText: helperText,
    HelperTextProps: HelperTextProps
  }, FormFieldGridProps), /*#__PURE__*/React.createElement(FormField, _extends({}, FormFieldProps, invalid && {
    error: {
      content: meta.error || meta.submitError,
      pointing: 'left'
    }
  }, {
    label: /*#__PURE__*/React.createElement(Header, _extends({}, HeaderProps, {
      className: clsx(headerClassname, (_clsx = {}, _defineProperty(_clsx, classes.header, true), _defineProperty(_clsx, classes.error, invalid), _defineProperty(_clsx, classes.required, isRequired), _clsx))
    }), label)
  })), /*#__PURE__*/React.createElement("div", _extends({}, OptionsListProps, {
    className: clsx(classes.items, optionsClassName)
  }), children));
};

Wrapper.propTypes = _objectSpread({}, wrapperProps);

var MultipleChoiceList = function MultipleChoiceList(_ref3) {
  var FormFieldGridProps = _ref3.FormFieldGridProps,
      FormFieldProps = _ref3.FormFieldProps,
      HeaderProps = _ref3.HeaderProps,
      OptionsListProps = _ref3.OptionsListProps,
      HelperTextProps = _ref3.HelperTextProps,
      props = _objectWithoutProperties(_ref3, _excluded5);

  return /*#__PURE__*/React.createElement(CheckboxContext.Provider, {
    value: {
      props: props,
      FormFieldGridProps: FormFieldGridProps,
      FormFieldProps: FormFieldProps,
      HeaderProps: HeaderProps,
      OptionsListProps: OptionsListProps,
      HelperTextProps: HelperTextProps
    }
  }, /*#__PURE__*/React.createElement(MultipleChoiceListCommon, _extends({}, props, {
    Wrapper: Wrapper,
    Checkbox: FinalCheckbox
  })));
};

MultipleChoiceList.propTypes = {
  FormFieldGridProps: PropTypes.object,
  FormFieldProps: PropTypes.object,
  HeaderProps: PropTypes.object,
  OptionsListProps: PropTypes.object,
  HelperTextProps: PropTypes.object
};
MultipleChoiceList.defaultProps = {
  FormFieldGridProps: {},
  FormFieldProps: {},
  HeaderProps: {},
  OptionsListProps: {},
  HelperTextProps: {}
};
export default MultipleChoiceList;

==> suir-component-mapper-4.0.0.tgz: package/esm/checkbox/multiple-choice-list.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["label", "isDisabled"],
    _excluded2 = ["isRequired", "isReadOnly", "helperText", "validate", "isDisabled", "meta"],
    _excluded3 = ["className"],
    _excluded4 = ["className"],
    _excluded5 = ["FormFieldGridProps", "FormFieldProps", "HeaderProps", "OptionsListProps", "HelperTextProps"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React, { createContext, useContext } from 'react';
import PropTypes from 'prop-types';
import MultipleChoiceListCommon, { wrapperProps } from '@data-driven-forms/common/multiple-choice-list';
import FormCheckbox from "semantic-ui-react/dist/es/collections/Form/FormCheckbox.js";
import Header from "semantic-ui-react/dist/es/elements/Header/Header.js";
import FormField from "semantic-ui-react/dist/es/collections/Form/FormField.js";
import { createUseStyles } from "react-jss/dist/react-jss.esm.js";
import clsx from 'clsx';
import { validationError } from '../helpers/helpers';
import FormFieldGrid from '../form-field-grid/form-field-grid';
var useStyles = createUseStyles({
  header: {
    marginBottom: '0 !important',
    display: 'inline',
    fontSize: '0.92857143em !important'
  },
  error: {
    color: '#9f3a38 !important'
  },
  items: {
    marginBottom: '1em'
  },
  required: {
    '&:after': {
      content: '"*"',
      margin: '-0.2em 0 0 0.2em',
      color: '#db2828'
    }
  }
});
var CheckboxContext = /*#__PURE__*/createContext({});

var FinalCheckbox = function FinalCheckbox(_ref) {
  var label = _ref.label,
      _isDisabled = _ref.isDisabled,
      rest = _objectWithoutProperties(_ref, _excluded);

  var _useContext = useContext(CheckboxContext),
      _useContext$props = _useContext.props,
      isRequired = _useContext$props.isRequired,
      isReadOnly = _useContext$props.isReadOnly,
      helperText = _useContext$props.helperText,
      validate = _useContext$props.validate,
      isDisabled = _useContext$props.isDisabled,
      meta = _useContext$props.meta,
      props = _objectWithoutProperties(_useContext$props, _excluded2);

  return /*#__PURE__*/React.createElement(FormCheckbox, _extends({}, rest, props, {
    disabled: isDisabled,
    label: label
  }));
};

FinalCheckbox.propTypes = {
  isDisabled: PropTypes.bool,
  label: PropTypes.node
};

var Wrapper = function Wrapper(_ref2) {
  var _clsx;

  var label = _ref2.label,
      isRequired = _ref2.isRequired,
      children = _ref2.children,
      meta = _ref2.meta,
      validateOnMount = _ref2.validateOnMount,
      helperText = _ref2.helperText;
  var invalid = validationError(meta, validateOnMount);
  var classes = useStyles();

  var _useContext2 = useContext(CheckboxContext),
      FormFieldGridProps = _useContext2.FormFieldGridProps,
      FormFieldProps = _useContext2.FormFieldProps,
      HelperTextProps = _useContext2.HelperTextProps,
      _useContext2$OptionsL = _useContext2.OptionsListProps,
      optionsClassName = _useContext2$OptionsL.className,
      OptionsListProps = _objectWithoutProperties(_useContext2$OptionsL, _excluded3),
      _useContext2$HeaderPr = _useContext2.HeaderProps,
      headerClassname = _useContext2$HeaderPr.className,
      HeaderProps = _objectWithoutProperties(_useContext2$HeaderPr, _excluded4);

  return /*#__PURE__*/React.createElement(FormFieldGrid, _extends({
    helperText: helperText,
    HelperTextProps: HelperTextProps
  }, FormFieldGridProps), /*#__PURE__*/React.createElement(FormField, _extends({}, FormFieldProps, invalid && {
    error: {
      content: meta.error || meta.submitError,
      pointing: 'left'
    }
  }, {
    label: /*#__PURE__*/React.createElement(Header, _extends({}, HeaderProps, {
      className: clsx(headerClassname, (_clsx = {}, _defineProperty(_clsx, classes.header, true), _defineProperty(_clsx, classes.error, invalid), _defineProperty(_clsx, classes.required, isRequired), _clsx))
    }), label)
  })), /*#__PURE__*/React.createElement("div", _extends({}, OptionsListProps, {
    className: clsx(classes.items, optionsClassName)
  }), children));
};

Wrapper.propTypes = _objectSpread({}, wrapperProps);

var MultipleChoiceList = function MultipleChoiceList(_ref3) {
  var _ref3$FormFieldGridPr = _ref3.FormFieldGridProps,
      FormFieldGridProps = _ref3$FormFieldGridPr === void 0 ? {} : _ref3$FormFieldGridPr,
      _ref3$FormFieldProps = _ref3.FormFieldProps,
      FormFieldProps = _ref3$FormFieldProps === void 0 ? {} : _ref3$FormFieldProps,
      _ref3$HeaderProps = _ref3.HeaderProps,
      HeaderProps = _ref3$HeaderProps === void 0 ? {} : _ref3$HeaderProps,
      _ref3$OptionsListProp = _ref3.OptionsListProps,
      OptionsListProps = _ref3$OptionsListProp === void 0 ? {} : _ref3$OptionsListProp,
      _ref3$HelperTextProps = _ref3.HelperTextProps,
      HelperTextProps = _ref3$HelperTextProps === void 0 ? {} : _ref3$HelperTextProps,
      props = _objectWithoutProperties(_ref3, _excluded5);

  return /*#__PURE__*/React.createElement(CheckboxContext.Provider, {
    value: {
      props: props,
      FormFieldGridProps: FormFieldGridProps,
      FormFieldProps: FormFieldProps,
      HeaderProps: HeaderProps,
      OptionsListProps: OptionsListProps,
      HelperTextProps: HelperTextProps
    }
  }, /*#__PURE__*/React.createElement(MultipleChoiceListCommon, _extends({}, props, {
    Wrapper: Wrapper,
    Checkbox: FinalCheckbox
  })));
};

MultipleChoiceList.propTypes = {
  FormFieldGridProps: PropTypes.object,
  FormFieldProps: PropTypes.object,
  HeaderProps: PropTypes.object,
  OptionsListProps: PropTypes.object,
  HelperTextProps: PropTypes.object
};
export default MultipleChoiceList;
